@@ -5,7 +5,7 @@ import copy
 from numbers import Real
 from typing import Any, Callable, Iterable, Optional, Tuple, Union
 from funfact.lang._ast import _ASNode, _AST, Primitives as P
-from funfact.lang._tensor import AbstractIndex, AbstractTensor
+from funfact.lang._terminal import AbstractIndex, AbstractTensor, LiteralValue
 from funfact.util.iterable import flatten_if
 
 
@@ -44,7 +44,7 @@ class ROOFInterpreter(ABC):
     by another transcribe interpreter.'''
 
     @abstractmethod
-    def scalar(self, value: Real, **payload: Any):
+    def literal(self, value: LiteralValue, **payload: Any):
         pass
 
     @abstractmethod
@@ -52,7 +52,8 @@ class ROOFInterpreter(ABC):
         pass
 
     @abstractmethod
-    def index(self, item: AbstractIndex, mustkeep: bool, **payload: Any):
+    def index(self, item: AbstractIndex, bound: bool, kron: bool,
+              **payload: Any):
         pass
 
     @abstractmethod
@@ -82,6 +83,10 @@ class ROOFInterpreter(ABC):
             pairwise: str, outidx: Any, **payload: Any):
         pass
 
+    @abstractmethod
+    def tran(self, src: Any, indices: Iterable[Any]):
+        pass
+
     def __call__(self, node: _ASNode, parent: _ASNode = None):
         fields_fixed = {
             name: _deep_apply(self, value, node)
@@ -117,7 +122,7 @@ class TranscribeInterpreter(ABC):
             return wrapper
 
     @abstractmethod
-    def scalar(self, value: Real, **payload: Any):
+    def literal(self, value: LiteralValue, **payload: Any):
         pass
 
     @abstractmethod
@@ -125,7 +130,8 @@ class TranscribeInterpreter(ABC):
         pass
 
     @abstractmethod
-    def index(self, item: AbstractIndex, mustkeep: bool, **payload: Any):
+    def index(self, item: AbstractIndex, bound: bool, kron: bool,
+              **payload: Any):
         pass
 
     @abstractmethod
@@ -155,6 +161,10 @@ class TranscribeInterpreter(ABC):
             pairwise: str, outidx: Optional[P.indices], **payload: Any):
         pass
 
+    @abstractmethod
+    def tran(self, src: Numeric, indices: P.indices):
+        pass
+
     def __call__(self, node: _ASNode, parent: _ASNode = None):
         node = copy.copy(node)
         for name, value in node.fields_fixed.items():
@@ -169,7 +179,7 @@ class TranscribeInterpreter(ABC):
         elif isinstance(payload, tuple) and len(payload) == 2:
             setattr(node, *payload)
         else:
-            raise TypeError(f'Uncognizable type for payload {payload}')
+            raise TypeError(f'Unrecognizable type for payload {payload}')
         return node
 
     def __ror__(self, tsrex: _AST):
@@ -194,9 +204,31 @@ class PayloadMerger:
         return type(tsrex_list[0])(self(*[tsrex.root for tsrex in tsrex_list]))
 
 
+class NoOp:
+    '''An interpreter that does nothing.'''
+    def __call__(self, node, **kwargs):
+        return node
+
+    def __ror__(self, tsrex):
+        return tsrex
+
+
+def dfs(node: _ASNode):
+    '''Returns an iterator that loop over all nodes in an AST in a depth-first
+    manner.'''
+
+    for child in flatten_if(
+        node.fields_fixed.values(),
+        lambda elem: isinstance(elem, (list, tuple))
+    ):
+        if isinstance(child, _ASNode):
+            yield from dfs(child)
+        yield node
+
+
 def dfs_filter(function: Callable[[_ASNode], bool], node: _ASNode):
     '''Returns an iterator that loop over all nodes in an AST in a depth-first
-    manner for which `function` evaluates to trues.'''
+    manner for which `function` evaluates to true.'''
 
     for child in flatten_if(
         node.fields_fixed.values(),
