@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-import jax.numpy as np
+from funfact.backend import active_backend as ab
 from ._base import ROOFInterpreter
 from ._einop import _einop
 
@@ -13,13 +13,13 @@ class Evaluator(ROOFInterpreter):
     def _binary_operator(reduction, pairwise, lhs, rhs, spec):
         return _einop(spec, lhs, rhs, reduction, pairwise)
 
-    def scalar(self, value, **kwargs):
-        return value
+    def literal(self, value, **kwargs):
+        return ab.tensor(value.raw)
 
     def tensor(self, abstract, data, **kwargs):
         return data
 
-    def index(self, item, mustkeep, **kwargs):
+    def index(self, item, bound, kron, **kwargs):
         return None
 
     def indices(self, items, **kwargs):
@@ -29,10 +29,10 @@ class Evaluator(ROOFInterpreter):
         return tensor
 
     def call(self, f, x, **kwargs):
-        return getattr(np, f)(x)
+        return getattr(ab, f)(x)
 
     def pow(self, base, exponent, **kwargs):
-        return np.power(base, exponent)
+        return ab.power(base, exponent)
 
     def neg(self, x, **kwargs):
         return -x
@@ -40,3 +40,7 @@ class Evaluator(ROOFInterpreter):
     def ein(self, lhs, rhs, precedence, reduction, pairwise, outidx, einspec,
             **kwargs):
         return self._binary_operator(reduction, pairwise, lhs, rhs, einspec)
+
+    def tran(self, src, indices, einspec, **kwargs):
+        in_spec, out_spec = einspec.split('->')
+        return ab.transpose(src, [in_spec.index(i) for i in out_spec])
