@@ -1,46 +1,36 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-import copy
-import jax.numpy as np
-import jax
+from funfact.backend import active_backend as ab
 from ._base import TranscribeInterpreter
 
 
-class JaxRng:
-
-    def __init__(self, key=0):
-        self.key = jax.random.PRNGKey(key)
-
-    def normal(self, size, scale=1, dtype=np.float32):
-        self.key, subkey = jax.random.split(self.key)
-        return scale * jax.random.normal(subkey, size, dtype)
-
-
 class LeafInitializer(TranscribeInterpreter):
     '''Creates numeric tensors for the leaf nodes in an AST.'''
 
-    def __init__(self, seed=0):
-        self.rng = JaxRng(seed)
+    def __init__(self):
+        super().__init__()
 
     as_payload = TranscribeInterpreter.as_payload('data')
 
     @as_payload
-    def scalar(self, value, **kwargs):
+    def literal(self, value, **kwargs):
         return None
 
     @as_payload
     def tensor(self, abstract, **kwargs):
         if abstract.initializer is not None:
             if not callable(abstract.initializer):
-                init_val = copy.deepcopy(abstract.initializer)
+                init_val = ab.tensor(abstract.initializer,
+                                     optimizable=abstract.optimizable)
             else:
                 init_val = abstract.initializer(abstract.shape)
         else:
-            init_val = self.rng.normal(abstract.shape)
+            init_val = ab.normal(0.0, 1.0, *abstract.shape,
+                                 optimizable=abstract.optimizable)
         return init_val
 
     @as_payload
-    def index(self, item, mustkeep, **kwargs):
+    def index(self, item, bound, kron, **kwargs):
         return None
 
     @as_payload
@@ -66,3 +56,7 @@ class LeafInitializer(TranscribeInterpreter):
     @as_payload
     def ein(self, lhs, rhs, precedence, reduction, pairwise, outidx, **kwargs):
         return None
+
+    @as_payload
+    def tran(self, src, indices, **kwargs):
+        return None
