@@ -5,9 +5,9 @@ from ._base import ROOFInterpreter
 
 _omap = dict(
     add='+',
-    sub='-',
-    mul=r'\times',
-    div='/',
+    subtract='-',
+    multiply=r'\times',
+    divide='/',
     min=r'\min',
     max=r'\max',
     log_sum_exp='LSE',
@@ -27,14 +27,19 @@ class LatexRenderer(ROOFInterpreter):
         else:
             return value
 
-    def scalar(self, value, **kwargs):
-        return str(value)
+    def literal(self, value, **kwargs):
+        return value._repr_tex_()
 
     def tensor(self, abstract, **kwargs):
         return abstract._repr_tex_()
 
-    def index(self, item, mustkeep, **kwargs):
-        accent = r'\widetilde' if mustkeep else None
+    def index(self, item, bound, kron, **kwargs):
+        if bound:
+            accent = r'\widetilde'
+        elif kron:
+            accent = r'\overset{\otimes}'
+        else:
+            accent = None
         return fr'{{{item._repr_tex_(accent=accent)}}}'
 
     def indices(self, items, **kwargs):
@@ -62,3 +67,6 @@ class LatexRenderer(ROOFInterpreter):
         body = fr'{lhs} {op} {rhs}'
         suffix = fr'\rightarrow_{{{outidx}}}' if outidx is not None else ''
         return body + suffix
+
+    def tran(self, src, indices, **kwargs):
+        return fr'{{{src}}}\rightarrow_{{{indices}}}'
