@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+from funfact.backend import active_backend as ab
 from funfact.lang._ast import _ASNode, _AST, Primitives as P
 from ._base import _deep_apply
-from funfact.util.typing import _is_tensor
 
 
 class SyntaxValidator:
@@ -12,21 +12,26 @@ class SyntaxValidator:
     may still accept a 'payload' argument, which could be potentially produced
     by another transcribe interpreter.'''
 
-    def scalar(self, node: _ASNode, parent: _ASNode):
+    def literal(self, node: _ASNode, parent: _ASNode):
         pass
 
     def tensor(self, node: _ASNode, parent: _ASNode):
         abst = node.abstract
         ini = node.abstract.initializer
-        if _is_tensor(ini):
+        if ab.is_tensor(ini):
             if ini.shape != abst.shape:
                 raise SyntaxError(
                     f'The shape {abst.shape} of tensor {abst} does not match '
                     f'its concrete-tensor initializer of {ini.shape}.'
                 )
 
-    def index(self, node: _ASNode, mustkeep: bool, parent: _ASNode):
-        pass
+    def index(self, node: _ASNode, parent: _ASNode):
+        i = node.item
+        if i.bound and i.kron:
+            raise SyntaxError(
+                f'Index {i} should not simultaneous imply elementwise and '
+                f'Kronecker product operations.'
+            )
 
     def indices(self, node: _ASNode, parent: _ASNode):
         for i in node.items:
